@@ -4,7 +4,7 @@
 
 cfg_if::cfg_if! {
     if #[cfg(any(target_os = "linux", target_os = "macos", target_os = "windows"))] {
-        pub mod heim;
-        pub use self::heim::*;
+        pub mod general;
+        pub use self::general::*;
     }
 }
