@@ -333,7 +333,6 @@ impl Default for ProcColumn {
     }
 }
 
-// TODO: [SORTING] Sort by clicking on column header (ie: click on cpu, sort/invert cpu sort)?
 impl ProcColumn {
     /// Returns its new status.
     pub fn toggle(&mut self, column: &ProcessSorting) -> Option<bool> {
@@ -384,7 +383,7 @@ impl ProcColumn {
         self.ordered_columns
             .iter()
             .filter_map(|column_type| {
-                if let Some(col_map) = self.column_mapping.get(&column_type) {
+                if let Some(col_map) = self.column_mapping.get(column_type) {
                     if col_map.enabled {
                         Some(1)
                     } else {
@@ -430,7 +429,7 @@ impl ProcColumn {
         self.ordered_columns
             .iter()
             .filter_map(|column_type| {
-                let mapping = self.column_mapping.get(&column_type).unwrap();
+                let mapping = self.column_mapping.get(column_type).unwrap();
                 let mut command_str = String::default();
                 if let Some(command) = mapping.shortcut {
                     command_str = format!("({})", command);
@@ -439,8 +438,8 @@ impl ProcColumn {
                 if mapping.enabled {
                     Some(format!(
                         "{}{}{}",
-                        column_type.to_string(),
-                        command_str.as_str(),
+                        column_type,
+                        command_str,
                         if proc_sorting_type == column_type {
                             if sort_reverse {
                                 DOWN_ARROW
@@ -511,6 +510,10 @@ impl ProcWidgetState {
             columns.toggle(&ProcessSorting::Mem);
             columns.toggle(&ProcessSorting::MemPercent);
         }
+        if is_using_command {
+            columns.toggle(&ProcessSorting::ProcessName);
+            columns.toggle(&ProcessSorting::Command);
+        }
 
         ProcWidgetState {
             process_search_state,
